Stan Math Library: stan/math/rev/mat/fun/typedefs.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Typedefs
typedefs.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/rev/core.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Typedefs
typedef Eigen::Matrix< var, Eigen::Dynamic, Eigen::Dynamic > | stan::math::matrix_v
| The type of a matrix holding `stan::math::var` values. More...
typedef Eigen::Matrix< var, Eigen::Dynamic, 1 > | stan::math::vector_v
| The type of a (column) vector holding `stan::math::var` values. More...
typedef Eigen::Matrix< var, 1, Eigen::Dynamic > | stan::math::row_vector_v
| The type of a row vector holding `stan::math::var` values. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.